From b4dc78de871ec9dd115db4b80994daac666a9593 Mon Sep 17 00:00:00 2001
From: Francois-Rene Rideau <tunes@google.com>
Date: Tue, 8 Oct 2013 18:32:04 -0400
Subject: [PATCH] Cleanup: use the name uiop and uiop/foo instead of
 asdf/driver and asdf/foo in the code.

---
 action.lisp              |  2 +-
 backward-internals.lisp  |  2 +-
 bundle.lisp              |  2 +-
 cache.lisp               |  2 +-
 component.lisp           |  2 +-
 concatenate-source.lisp  |  2 +-
 defsystem.lisp           |  2 +-
 find-component.lisp      |  2 +-
 find-system.lisp         |  4 +++-
 footer.lisp              |  2 +-
 interface.lisp           |  2 +-
 lisp-action.lisp         |  4 ++--
 operate.lisp             |  2 +-
 operation.lisp           |  2 +-
 output-translations.lisp |  4 ++--
 plan.lisp                |  2 +-
 source-registry.lisp     |  2 +-
 system.lisp              |  2 +-
 uiop/driver.lisp         | 10 ++++++----
 uiop/package.lisp        |  2 +-
 uiop/stream.lisp         |  2 +-
 uiop/utility.lisp        |  6 +++---
 upgrade.lisp             |  4 ++--
 23 files changed, 35 insertions(+), 31 deletions(-)

diff --git a/action.lisp b/action.lisp
index 311c3f401..8df6719b1 100644
--- a/action.lisp
+++ b/action.lisp
@@ -4,7 +4,7 @@
 (asdf/package:define-package :asdf/action
   (:nicknames :asdf-action)
   (:recycle :asdf/action :asdf)
-  (:use :asdf/common-lisp :asdf/driver :asdf/upgrade
+  (:use :uiop/common-lisp :uiop :asdf/upgrade
    :asdf/component :asdf/system #:asdf/cache :asdf/find-system :asdf/find-component :asdf/operation)
   (:export
    #:action #:define-convenience-action-methods
diff --git a/backward-internals.lisp b/backward-internals.lisp
index 2f37a8279..0ecb7dd5e 100644
--- a/backward-internals.lisp
+++ b/backward-internals.lisp
@@ -3,7 +3,7 @@
 
 (asdf/package:define-package :asdf/backward-internals
   (:recycle :asdf/backward-internals :asdf)
-  (:use :asdf/common-lisp :asdf/driver :asdf/upgrade
+  (:use :uiop/common-lisp :uiop :asdf/upgrade
    :asdf/system :asdf/component :asdf/operation
    :asdf/find-system :asdf/action :asdf/lisp-action)
   (:export ;; for internal use
diff --git a/bundle.lisp b/bundle.lisp
index 2d71f4588..2cf8c0763 100644
--- a/bundle.lisp
+++ b/bundle.lisp
@@ -3,7 +3,7 @@
 
 (asdf/package:define-package :asdf/bundle
   (:recycle :asdf/bundle :asdf)
-  (:use :asdf/common-lisp :asdf/driver :asdf/upgrade
+  (:use :uiop/common-lisp :uiop :asdf/upgrade
    :asdf/component :asdf/system :asdf/find-system :asdf/find-component :asdf/operation
    :asdf/action :asdf/lisp-action :asdf/plan :asdf/operate)
   (:export
diff --git a/cache.lisp b/cache.lisp
index 1d8a7936b..6b6bd1b02 100644
--- a/cache.lisp
+++ b/cache.lisp
@@ -2,7 +2,7 @@
 ;;;; Stamp cache
 
 (asdf/package:define-package :asdf/cache
-  (:use :asdf/common-lisp :asdf/driver :asdf/upgrade)
+  (:use :uiop/common-lisp :uiop :asdf/upgrade)
   (:export #:get-file-stamp #:compute-file-stamp #:register-file-stamp
            #:consult-asdf-cache #:do-asdf-cache
            #:call-with-asdf-cache #:with-asdf-cache #:*asdf-cache*))
diff --git a/component.lisp b/component.lisp
index e7fb7d917..084d61bd7 100644
--- a/component.lisp
+++ b/component.lisp
@@ -3,7 +3,7 @@
 
 (asdf/package:define-package :asdf/component
   (:recycle :asdf/component :asdf/defsystem :asdf/find-system :asdf)
-  (:use :asdf/common-lisp :asdf/driver :asdf/upgrade)
+  (:use :uiop/common-lisp :uiop :asdf/upgrade)
   (:export
    #:component #:component-find-path
    #:component-name #:component-pathname #:component-relative-pathname
diff --git a/concatenate-source.lisp b/concatenate-source.lisp
index 2cb3d5e21..a8e7fb1ba 100644
--- a/concatenate-source.lisp
+++ b/concatenate-source.lisp
@@ -3,7 +3,7 @@
 
 (asdf/package:define-package :asdf/concatenate-source
   (:recycle :asdf/concatenate-source :asdf)
-  (:use :asdf/common-lisp :asdf/driver :asdf/upgrade
+  (:use :uiop/common-lisp :uiop :asdf/upgrade
    :asdf/component :asdf/operation
    :asdf/system :asdf/find-system :asdf/defsystem
    :asdf/action :asdf/lisp-action :asdf/bundle)
diff --git a/defsystem.lisp b/defsystem.lisp
index 8f3a55001..758db0114 100644
--- a/defsystem.lisp
+++ b/defsystem.lisp
@@ -3,7 +3,7 @@
 
 (asdf/package:define-package :asdf/defsystem
   (:recycle :asdf/defsystem :asdf)
-  (:use :asdf/common-lisp :asdf/driver :asdf/upgrade
+  (:use :uiop/common-lisp :uiop :asdf/upgrade
    :asdf/component :asdf/system :asdf/cache
    :asdf/find-system :asdf/find-component :asdf/lisp-action :asdf/operate
    :asdf/backward-internals)
diff --git a/find-component.lisp b/find-component.lisp
index 28568dc0e..98f392862 100644
--- a/find-component.lisp
+++ b/find-component.lisp
@@ -3,7 +3,7 @@
 
 (asdf/package:define-package :asdf/find-component
   (:recycle :asdf/find-component :asdf)
-  (:use :asdf/common-lisp :asdf/driver :asdf/upgrade
+  (:use :uiop/common-lisp :uiop :asdf/upgrade
    :asdf/component :asdf/system :asdf/find-system)
   (:export
    #:find-component
diff --git a/find-system.lisp b/find-system.lisp
index 43681ef15..5486ebf99 100644
--- a/find-system.lisp
+++ b/find-system.lisp
@@ -3,7 +3,7 @@
 
 (asdf/package:define-package :asdf/find-system
   (:recycle :asdf/find-system :asdf)
-  (:use :asdf/common-lisp :asdf/driver :asdf/upgrade
+  (:use :uiop/common-lisp :uiop :asdf/upgrade
    :asdf/component :asdf/system :asdf/cache)
   (:export
    #:remove-entry-from-registry #:coerce-entry-to-directory
@@ -243,7 +243,9 @@ Going forward, we recommend new users should be using the source-registry.
     (setf (gethash (coerce-name system-name) *preloaded-systems*) keys))
 
   (register-preloaded-system "asdf" :version *asdf-version*)
+  (register-preloaded-system "uiop" :version *asdf-version*)
   (register-preloaded-system "asdf-driver" :version *asdf-version*)
+  (register-preloaded-system "asdf-defsystem" :version *asdf-version*)
 
   (defmethod find-system ((name null) &optional (error-p t))
     (declare (ignorable name))
diff --git a/footer.lisp b/footer.lisp
index d7b5ca629..286bbfabd 100644
--- a/footer.lisp
+++ b/footer.lisp
@@ -3,7 +3,7 @@
 
 (asdf/package:define-package :asdf/footer
   (:recycle :asdf/footer :asdf)
-  (:use :asdf/common-lisp :asdf/driver :asdf/upgrade
+  (:use :uiop/common-lisp :uiop :asdf/upgrade
    :asdf/find-system :asdf/find-component :asdf/operation :asdf/action :asdf/lisp-action
    :asdf/operate :asdf/bundle :asdf/concatenate-source
    :asdf/output-translations :asdf/source-registry
diff --git a/interface.lisp b/interface.lisp
index 84e80add0..27e4fc3a7 100644
--- a/interface.lisp
+++ b/interface.lisp
@@ -10,7 +10,7 @@
    #:split #:make-collector
    #:loaded-systems ; makes for annoying SLIME completion
    #:output-files-for-system-and-operation) ; obsolete ASDF-BINARY-LOCATION function
-  (:use :asdf/common-lisp :asdf/driver :asdf/upgrade :asdf/cache
+  (:use :uiop/common-lisp :uiop :asdf/upgrade :asdf/cache
    :asdf/component :asdf/system :asdf/find-system :asdf/find-component
    :asdf/operation :asdf/action :asdf/lisp-action
    :asdf/output-translations :asdf/source-registry
diff --git a/lisp-action.lisp b/lisp-action.lisp
index b8213d5fa..8dfce3a26 100644
--- a/lisp-action.lisp
+++ b/lisp-action.lisp
@@ -4,8 +4,8 @@
 (asdf/package:define-package :asdf/lisp-action
   (:recycle :asdf/lisp-action :asdf)
   (:intern #:proclamations #:flags)
-  (:use :asdf/common-lisp :asdf/driver :asdf/upgrade
-   :asdf/cache :asdf/component :asdf/system :asdf/find-component :asdf/find-system
+  (:use :uiop/common-lisp :uiop :asdf/upgrade :asdf/cache
+   :asdf/component :asdf/system :asdf/find-component :asdf/find-system
    :asdf/operation :asdf/action)
   (:export
    #:try-recompiling
diff --git a/operate.lisp b/operate.lisp
index 84e1b25c8..c8c8f66cf 100644
--- a/operate.lisp
+++ b/operate.lisp
@@ -3,7 +3,7 @@
 
 (asdf/package:define-package :asdf/operate
   (:recycle :asdf/operate :asdf)
-  (:use :asdf/common-lisp :asdf/driver :asdf/upgrade
+  (:use :uiop/common-lisp :uiop :asdf/upgrade
    :asdf/component :asdf/system :asdf/operation :asdf/action
    :asdf/find-system :asdf/find-component :asdf/lisp-action :asdf/plan)
   (:export
diff --git a/operation.lisp b/operation.lisp
index 989f8dbb9..16ac48756 100644
--- a/operation.lisp
+++ b/operation.lisp
@@ -3,7 +3,7 @@
 
 (asdf/package:define-package :asdf/operation
   (:recycle :asdf/operation :asdf/action :asdf) ;; asdf/action for FEATURE pre 2.31.5.
-  (:use :asdf/common-lisp :asdf/driver :asdf/upgrade)
+  (:use :uiop/common-lisp :uiop :asdf/upgrade)
   (:export
    #:operation
    #:operation-original-initargs #:original-initargs ;; backward-compatibility only. DO NOT USE.
diff --git a/plan.lisp b/plan.lisp
index 6ff2b0cb5..a7cfb1fd8 100644
--- a/plan.lisp
+++ b/plan.lisp
@@ -3,7 +3,7 @@
 
 (asdf/package:define-package :asdf/plan
   (:recycle :asdf/plan :asdf)
-  (:use :asdf/common-lisp :asdf/driver :asdf/upgrade
+  (:use :uiop/common-lisp :uiop :asdf/upgrade
    :asdf/component :asdf/operation :asdf/system
    :asdf/cache :asdf/find-system :asdf/find-component
    :asdf/operation :asdf/action :asdf/lisp-action)
diff --git a/source-registry.lisp b/source-registry.lisp
index 60c62845d..da6ed0ced 100644
--- a/source-registry.lisp
+++ b/source-registry.lisp
@@ -4,7 +4,7 @@
 
 (asdf/package:define-package :asdf/source-registry
   (:recycle :asdf/source-registry :asdf)
-  (:use :asdf/common-lisp :asdf/driver :asdf/upgrade :asdf/find-system)
+  (:use :uiop/common-lisp :uiop :asdf/upgrade :asdf/find-system)
   (:export
    #:*source-registry-parameter* #:*default-source-registries*
    #:invalid-source-registry
diff --git a/system.lisp b/system.lisp
index e900f1cfd..ba2dfcd97 100644
--- a/system.lisp
+++ b/system.lisp
@@ -3,7 +3,7 @@
 
 (asdf/package:define-package :asdf/system
   (:recycle :asdf :asdf/system)
-  (:use :asdf/common-lisp :asdf/driver :asdf/upgrade :asdf/component)
+  (:use :uiop/common-lisp :uiop :asdf/upgrade :asdf/component)
   (:export
    #:system #:proto-system
    #:system-source-file #:system-source-directory #:system-relative-pathname
diff --git a/uiop/driver.lisp b/uiop/driver.lisp
index 6ef0a6b1e..d242ecb90 100644
--- a/uiop/driver.lisp
+++ b/uiop/driver.lisp
@@ -1,15 +1,17 @@
 ;;;; ---------------------------------------------------------------------------
-;;;; Re-export all the functionality in asdf/driver
+;;;; Re-export all the functionality in UIOP
 
 (uiop/package:define-package :uiop/driver
   (:nicknames :uiop :asdf/driver :asdf-driver :asdf-utils)
   (:use :uiop/common-lisp :uiop/package :uiop/utility
-    :uiop/os :uiop/pathname :uiop/stream :uiop/filesystem :uiop/image
+   :uiop/os :uiop/pathname :uiop/stream :uiop/filesystem :uiop/image
    :uiop/run-program :uiop/lisp-build
    :uiop/configuration :uiop/backward-driver)
   (:reexport
-   ;; NB: excluding asdf/common-lisp
-   ;; which include all of CL with compatibility modifications on select platforms.
+   ;; NB: excluding uiop/common-lisp
+   ;; which include all of CL with compatibility modifications on select platforms,
+   ;; that could cause potential conflicts for packages that would :use (cl uiop)
+   ;; or :use (closer-common-lisp uiop), etc.
    :uiop/package :uiop/utility
    :uiop/os :uiop/pathname :uiop/stream :uiop/filesystem :uiop/image
    :uiop/run-program :uiop/lisp-build
diff --git a/uiop/package.lisp b/uiop/package.lisp
index 584af0a20..d286b9805 100644
--- a/uiop/package.lisp
+++ b/uiop/package.lisp
@@ -8,7 +8,7 @@
   ;; CAUTION: we must handle the first few packages specially for hot-upgrade.
   ;; This package definition MUST NOT change unless its name too changes;
   ;; if/when it changes, don't forget to add new functions missing from below.
-  ;; Until then, asdf/package is frozen to forever
+  ;; Until then, uiop/package is frozen to forever
   ;; import and export the same exact symbols as for ASDF 2.27.
   ;; Any other symbol must be import-from'ed and re-export'ed in a different package.
   (:use :common-lisp)
diff --git a/uiop/stream.lisp b/uiop/stream.lisp
index d16309669..27e2de542 100644
--- a/uiop/stream.lisp
+++ b/uiop/stream.lisp
@@ -541,7 +541,7 @@ The file will be open with specified DIRECTION, ELEMENT-TYPE and EXTERNAL-FORMAT
       :for pathname = (pathname (format nil "~A~36R" prefix counter)) :do
         ;; TODO: on Unix, do something about umask
         ;; TODO: on Unix, audit the code so we make sure it uses O_CREAT|O_EXCL
-        ;; TODO: on Unix, use CFFI and mkstemp -- but asdf/driver is precisely meant to not depend on CFFI or on anything! Grrrr.
+        ;; TODO: on Unix, use CFFI and mkstemp -- but UIOP is precisely meant to not depend on CFFI or on anything! Grrrr.
         (with-open-file (stream pathname
                                 :direction direction
                                 :element-type element-type
diff --git a/uiop/utility.lisp b/uiop/utility.lisp
index d93170dde..eecd7a6b3 100644
--- a/uiop/utility.lisp
+++ b/uiop/utility.lisp
@@ -5,7 +5,7 @@
   (:nicknames :asdf/utility)
   (:recycle :uiop/utility :asdf/utility :asdf)
   (:use :uiop/common-lisp :uiop/package)
-  ;; import and reexport a few things defined in :asdf/common-lisp
+  ;; import and reexport a few things defined in :uiop/common-lisp
   (:import-from :uiop/common-lisp #:compatfmt #:loop* #:frob-substrings
    #+ecl #:use-ecl-byte-compiler-p #+mcl #:probe-posix)
   (:export #:compatfmt #:loop* #:frob-substrings #:compatfmt
@@ -68,9 +68,9 @@
                  ;; undefining the previous function is the portable way
                  ;; of overriding any incompatible previous gf, except on CLISP.
                  ;; We usually try to do it only for the functions that need it,
-                 ;; which happens in asdf/upgrade - however, for ECL, we need this hammer,
+                 ;; which happens in asdf/upgrade - however, for ECL, we need this hammer
                  ;; (which causes issues in clisp)
-                 ,@(when (or #-clisp supersede #+(or ecl gcl2.7) t) ; XXX
+                 ,@(when (or #-clisp supersede #+(or ecl gcl2.7) t)
                      `((undefine-function ',name)))
                  #-gcl ; gcl 2.7.0 notinline functions lose secondary return values :-(
                  ,@(when (and #+ecl (symbolp name)) ; fails for setf functions on ecl
diff --git a/output-translations.lisp b/output-translations.lisp
index f0c5547a7..004557a30 100644
--- a/output-translations.lisp
+++ b/output-translations.lisp
@@ -3,7 +3,7 @@
 
 (asdf/package:define-package :asdf/output-translations
   (:recycle :asdf/output-translations :asdf)
-  (:use :asdf/common-lisp :asdf/driver :asdf/upgrade)
+  (:use :uiop/common-lisp :uiop :asdf/upgrade)
   (:export
    #:*output-translations* #:*output-translations-parameter*
    #:invalid-output-translation
@@ -282,7 +282,7 @@ effectively disabling the output translation facility."
               :return (translate-pathname* p absolute-source destination root source)
               :finally (return p)))))
 
   ;; Hook into asdf/driver's output-translation mechanism
   #-cormanlisp
   (setf *output-translation-function* 'apply-output-translations)
 
@@ -282,7 +282,7 @@ effectively disabling the output translation facility."
               :finally (return p)))))
 
-  ;; Hook into asdf/driver's output-translation mechanism
+  ;; Hook into uiop's output-translation mechanism
   #-cormanlisp
   (setf *output-translation-function* 'apply-output-translations)
diff --git a/upgrade.lisp b/upgrade.lisp
index bafc2ebf4..6b7e82311 100644
--- a/upgrade.lisp
+++ b/upgrade.lisp
@@ -4,7 +4,7 @@
 
 (asdf/package:define-package :asdf/upgrade
   (:recycle :asdf/upgrade :asdf)
-  (:use :asdf/common-lisp :asdf/driver)
+  (:use :uiop/common-lisp :uiop)
   (:export
    #:asdf-version #:*previous-asdf-versions* #:*asdf-version*
    #:asdf-message #:*verbose-out*
@@ -78,7 +78,7 @@ You can compare this string with e.g.: (ASDF:VERSION-SATISFIES (ASDF:ASDF-VERSIO
              #:inherit-source-registry #:process-source-registry ;; source-registry
              #:process-source-registry-directive
              #:trivial-system-p ;; bundle
              ;; NB: it's too late to do anything about asdf-driver functions!
              ))
          (uninterned-symbols
            '(#:*asdf-revision* #:around #:asdf-method-combination
@@ -78,7 +78,7 @@ You can compare this string with e.g.: (ASDF:VERSION-SATISFIES (ASDF:ASDF-VERSIO
              #:process-source-registry-directive
              #:trivial-system-p ;; bundle
-             ;; NB: it's too late to do anything about asdf-driver functions!
+             ;; NB: it's too late to do anything about uiop functions!
              ))
          (uninterned-symbols
-- 
GitLab